==> beetlsql-2.12.12.RELEASE-sources.jar: org/beetl/sql/test/MysqlDBConfig.java <==
package org.beetl.sql.test;

public class MysqlDBConfig {
//    public static String driver = "com.mysql.jdbc.Driver";
    public static String driver = "com.mysql.cj.jdbc.Driver";
    public static String dbName = "orm";
    public static String password = "123456";
    public static String userName = "root";
    public static String url = "jdbc:mysql://127.0.0.1:3306/" + dbName+"?&serverTimezone=UTC";
//    public static String url = "jdbc:mysql://127.0.0.1:3306/" + dbName+"?&serverTimezone=UTC&useSSL=false";




//    public static String driver = "com.ibm.db2.jcc.DB2Driver";
//    public static String dbName = "TESTDB";
//    public static String password = "db2inst1_1";
//    public static String userName = "db2inst1_1";
//    public static String url = "jdbc:db2://118.89.242.231:50000/TESTDB";

//    public static String driver = "com.microsoft.sqlserver.jdbc.SQLServerDriver";
//    public static String dbName = "dev";
//    public static String password = "develop";
//    public static String userName = "dev";
//    public static String url = "jdbc:sqlserver://175.102.10.132:1733;databaseName=dev";  ;

//    public static String driver = "oracle.jdbc.driver.OracleDriver";
//    public static String dbName = "risk";
//    public static String password = "risk";
//    public static String userName = "risk";
//    public static String url = "jdbc:oracle:thin:@172.16.86.56:1521:dfzb";

//  public static String driver = "org.postgresql.Driver";
//  public static String dbName = "postgres";
//  public static String password = "postgres";
//  public static String userName = "postgres";
//  public static String url = "jdbc:postgresql://192.168.1.68:5432/postgres";

}

==> beetlsql-2.13.0.RELEASE-sources.jar: org/beetl/sql/test/MysqlDBConfig.java <==
package org.beetl.sql.test;

public class MysqlDBConfig {
//    public static String driver = "com.mysql.jdbc.Driver";
    public static String driver = "com.mysql.cj.jdbc.Driver";
    public static String dbName = "test";
    public static String password = "12345678";
    public static String userName = "root";
    public static String url = "jdbc:mysql://127.0.0.1:13306/" + dbName+"?&serverTimezone=GMT%2B8&useSSL=false";
//    public static String url = "jdbc:mysql://127.0.0.1:3306/" + dbName+"?&serverTimezone=UTC&useSSL=false";




//    public static String driver = "com.ibm.db2.jcc.DB2Driver";
//    public static String dbName = "TESTDB";
//    public static String password = "db2inst1_1";
//    public static String userName = "db2inst1_1";
//    public static String url = "jdbc:db2://118.89.242.231:50000/TESTDB";

//    public static String driver = "com.microsoft.sqlserver.jdbc.SQLServerDriver";
//    public static String dbName = "dev";
//    public static String password = "develop";
//    public static String userName = "dev";
//    public static String url = "jdbc:sqlserver://175.102.10.132:1733;databaseName=dev";  ;

//    public static String driver = "oracle.jdbc.driver.OracleDriver";
//    public static String dbName = "risk";
//    public static String password = "risk";
//    public static String userName = "risk";
//    public static String url = "jdbc:oracle:thin:@172.16.86.56:1521:dfzb";

//  public static String driver = "org.postgresql.Driver";
//  public static String dbName = "orm";
//  public static String password = "postgres";
//  public static String userName = "postgres";
//  public static String url = "jdbc:postgresql://127.0.0.1:5432/orm";

}
